﻿namespace Dynamicweb.Ecommerce.LiveIntegration.Configuration
{
  /// <summary>
  /// Global constants class for all constant values in this project.
  /// </summary>
  internal static class Constants
  {
    /// <summary>
    /// Defines the name of the Live integration.
    /// </summary>
    public const string AddInName = "ERPLiveIntegrationAddIn";

    /// <summary>
    /// Defines the web service connection status cache key.
    /// </summary>
    public static readonly string WebServiceConnectionCacheKey = AddInName + "_WebServiceConnectionCacheKey";

    /// <summary>
    /// Nested class with ache configuration constants.
    /// </summary>
    internal static class CacheConfiguration
    {
      /// <summary>
      /// Defines the cache key used for storing fetched products. 
      /// </summary>
      public const string FetchProductInfoResult = "FetchProductInfoResult";

      /// <summary>
      ///  Defines the cache key used for storing order info. 
      /// </summary>
      public const string OrderCommunicationHash = "OrderCommunicationHash";
    }

    /// <summary>
    /// Defines the ways that the cart can communicate with the ERP.
    /// </summary>
    internal static class CartCommunicationType
    {
      /// <summary>
      /// Live integration does not send the cart or orders to the ERP.
      /// </summary>
      public const string None = "None";

      /// <summary>
      /// Info is sent to the ERP for cart calculation and completed orders.
      /// </summary>
      public const string Full = "Full";

      /// <summary>
      /// Info is sent to the ERP for completed orders only (which means Dynamicweb calculates the cart).
      /// </summary>
      public const string OnlyOnOrderComplete = "Only on Order Complete";
    }   
  }
}