﻿using Dynamicweb.Controls;
using Dynamicweb.Controls.Extensibility;
using Dynamicweb.SystemTools;
using System.Globalization;

namespace Dynamicweb.Ecommerce.LiveIntegration.RibbonBars
{
    /// <summary>
    /// Serves as the base class for all RibbonBar AddIns.
    /// </summary>
    /// <seealso cref="RibbonBarAddIn" />
    public abstract class RibbonBarBase : RibbonBarAddIn
    {
        /// <summary>
        /// The live integration tab
        /// </summary>
        private static readonly string LiveIntegrationTab = "Live Integration";

        /// <summary>
        /// Initializes a new instance of an object.
        /// </summary>
        /// <param name="ribbon">An instance of <see cref="T:Dynamicweb.Controls.RibbonBar">RibbonBar</see> object that contains an add-in.</param>
        protected RibbonBarBase(RibbonBar ribbon) : base(ribbon)
        {
        }

        /// <summary>
        /// Creates the export to XML button.
        /// </summary>
        /// <param name="group">The group.</param>
        /// <param name="buttonText">The button text.</param>
        /// <returns>RibbonBarButton.</returns>
        protected static RibbonBarButton CreateExportToXmlButton(RibbonBarGroup group, string buttonText)
        {
            using (var button = new RibbonBarButton())
            {
                button.Text = Translate.Translate(buttonText);
                button.Image = Controls.Icons.Icon.Type.DocumentNotebook;
                button.Size = Controls.Icons.Icon.Size.Large;

                group.AddItem(button);
                return button;
            }
        }

        /// <summary>
        /// Creates the transfer order button.
        /// </summary>
        /// <param name="group">The group.</param>
        /// <returns>RibbonBarButton.</returns>
        protected static RibbonBarButton CreateTransferOrderButton(RibbonBarGroup group)
        {
            using (var button = new RibbonBarButton())
            {
                button.Text = Translate.Translate("Transfer to ERP");
                button.Image = Controls.Icons.Icon.Type.Export;
                button.Size = Controls.Icons.Icon.Size.Large;

                group.AddItem(button);
                return button;
            }
        }       

        /// <summary>
        /// Streams the file.
        /// </summary>
        /// <param name="xml">The XML.</param>
        /// <param name="fileName">Name of the file.</param>
        protected static void StreamFile(string xml, string fileName)
        {
            Context.Current.Response.Clear();
            Context.Current.Response.AddHeader("Content-Disposition", $"attachment; filename={fileName}");
            Context.Current.Response.AddHeader("Content-Length", xml.Length.ToString(CultureInfo.InvariantCulture));
            Context.Current.Response.ContentType = "application/octet-stream";
            Context.Current.Response.Write(xml);
            Context.Current.Response.End();
        }

        /// <summary>
        /// Creates the live integration ribbon.
        /// </summary>
        /// <param name="groupName">Name of the group.</param>
        /// <returns>RibbonBarGroup.</returns>
        protected RibbonBarGroup CreateLiveIntegrationRibbon(string groupName)
        {
            return Ribbon.CreateGroup(LiveIntegrationTab, groupName);
        }
    }
}